[pitivi/ges: 201/287] Rename rendering dialog classes
- From: Jean-FranÃois Fortin Tam <jfft src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [pitivi/ges: 201/287] Rename rendering dialog classes
- Date: Thu, 15 Mar 2012 16:42:44 +0000 (UTC)
commit 0f7ab09cf65a51c07137b2f5045006ba30639a38
Author: Jean-FranÃois Fortin Tam <nekohayo gmail com>
Date: Tue Jan 10 12:12:11 2012 -0500
Rename rendering dialog classes
pitivi/autoaligner.py | 6 +++---
pitivi/mainwindow.py | 14 +++++++-------
pitivi/render.py | 12 ++++++------
3 files changed, 16 insertions(+), 16 deletions(-)
---
diff --git a/pitivi/mainwindow.py b/pitivi/mainwindow.py
index 99d35ae..7b7877e 100644
--- a/pitivi/mainwindow.py
+++ b/pitivi/mainwindow.py
@@ -210,27 +210,27 @@ class PitiviMainWindow(gtk.Window, Loggable):
self.app.action_log.connect("redo", self._actionLogRedo)
self.app.action_log.connect("cleaned", self._actionLogCleaned)
- def showEncodingDialog(self, project, pause=True):
+ def showRenderDialog(self, project, pause=True):
"""
- Shows the L{EncodingDialog} for the given project Timeline.
+ Shows the L{RenderDialog} for the given project Timeline.
@param project: The project
@type project: L{Project}
@param pause: If C{True}, pause the timeline before displaying the dialog.
@type pause: C{bool}
"""
- from pitivi.render import EncodingDialog
+ from pitivi.render import RenderDialog
- dialog = EncodingDialog(self, project)
- dialog.window.connect("destroy", self._renderingDialogDestroyCb)
+ dialog = RenderDialog(self, project)
+ dialog.window.connect("destroy", self._renderDialogDestroyCb)
self.set_sensitive(False)
dialog.window.show()
- def _renderingDialogDestroyCb(self, unused_dialog):
+ def _renderDialogDestroyCb(self, unused_dialog):
self.set_sensitive(True)
def _recordCb(self, unused_button):
- self.showEncodingDialog(self.project)
+ self.showRenderDialog(self.project)
def _setActions(self, instance):
PLAY = _("Start Playback")
diff --git a/pitivi/autoaligner.py b/pitivi/autoaligner.py
index 2f759bd..c83a951 100644
--- a/pitivi/autoaligner.py
+++ b/pitivi/autoaligner.py
@@ -654,7 +654,7 @@ class AutoAligner(Loggable):
class AlignmentProgressDialog:
""" Dialog indicating the progress of the auto-alignment process.
- Code derived from L{EncodingProgressDialog}, but greatly simplified
+ Code derived from L{RenderingProgressDialog}, but greatly simplified
(read-only, no buttons)."""
def __init__(self, app):
@@ -668,9 +668,9 @@ class AlignmentProgressDialog:
# Parent this dialog with mainwindow
# set_transient_for allows this dialog to properly
# minimize together with the mainwindow. This method is
# taken from EncodingProgressDialog. In both cases, it appears
# to work correctly, although there is a known bug for Gnome 3 in
- # EncodingProgressDialog (bug #652917)
+ # RenderingProgressDialog (bug #652917)
self.window.set_transient_for(app.gui)
# UI widgets
@@ -668,9 +668,9 @@ class AlignmentProgressDialog:
# set_transient_for allows this dialog to properly
# minimize together with the mainwindow. This method is
- # taken from EncodingProgressDialog. In both cases, it appears
+ # taken from RenderingProgressDialog. In both cases, it appears
# to work correctly, although there is a known bug for Gnome 3 in
diff --git a/pitivi/render.py b/pitivi/render.py
index 055e806..60064ed 100644
--- a/pitivi/render.py
+++ b/pitivi/render.py
@@ -313,7 +313,7 @@ def factorylist(factories):
#--------------------------------- Public classes -----------------------------#
-class EncodingProgressDialog(Signallable):
+class RenderingProgressDialog(Signallable):
__signals__ = {
"pause": [],
"cancel": [],
@@ -351,10 +351,10 @@ class EncodingProgressDialog(Signallable):
def setState(self, state):
if state == gst.STATE_PLAYING:
self.play_pause_button.props.label = gtk.STOCK_MEDIA_PAUSE
- self.system.inhibitSleep(EncodingDialog.INHIBIT_REASON)
+ self.system.inhibitSleep(RenderDialog.INHIBIT_REASON)
else:
self.play_pause_button.props.label = 'pitivi-render'
- self.system.uninhibitSleep(EncodingDialog.INHIBIT_REASON)
+ self.system.uninhibitSleep(RenderDialog.INHIBIT_REASON)
def _cancelButtonClickedCb(self, unused_button):
self.emit("cancel")
@@ -363,7 +363,7 @@ class EncodingProgressDialog(Signallable):
self.emit("pause")
-class EncodingDialog(Loggable):
+class RenderDialog(Loggable):
"""Render dialog box.
@ivar preferred_arenderer: The last audio renderer selected by the user.
@@ -795,7 +795,7 @@ class EncodingDialog(Loggable):
set_combo_value(self.sample_depth_combo, self.settings.audiodepth)
def _displayRenderSettings(self):
"""Display the settings which can be changed only in the EncodingDialog.
"""
# Video settings
# note: this will trigger an update of the video resolution label
@@ -955,7 +955,7 @@ class EncodingDialog(Loggable):
start the rendering process. """
self.outfile = os.path.join(self.filebutton.get_uri(),
self.fileentry.get_text())
- self.progress = EncodingProgressDialog(self.app, self)
+ self.progress = RenderingProgressDialog(self.app, self)
self.window.hide() # Hide the rendering settings dialog while rendering
# FIXME GES: Handle presets here!
[
@@ -795,7 +795,7 @@ class EncodingDialog(Loggable):
set_combo_value(self.sample_depth_combo, self.settings.audiodepth)
def _displayRenderSettings(self):
- """Display the settings which can be changed only in the EncodingDialog.
+ """Display the settings which can be changed only in the RenderDialog.
"""
# Video settings
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]